==> cloudproof-4.2.0.tar.gz: test/findex/redis_test.dart <==
import 'dart:convert';
import 'dart:developer';
import 'dart:io';
import 'dart:typed_data';

import 'package:cloudproof/cloudproof.dart';
import 'package:flutter_test/flutter_test.dart';

import 'findex_redis_implementation.dart';
import 'redis_multi_entry_tables.dart';

const expectedUsersIdsForFrance = [
  4,
  5,
  7,
  8,
  14,
  17,
  19,
  20,
  23,
  34,
  37,
  43,
  46,
  48,
  55,
  56,
  60,
  61,
  63,
  65,
  68,
  70,
  71,
  77,
  80,
  82,
  83,
  85,
  86,
  96
];

void main() {
  group('Findex Redis', () {
    test('search/upsert', () async {
      final masterKey = FindexMasterKey.fromJson(jsonDecode(
          await File('test/resources/findex/master_key.json').readAsString()));

      final label = Uint8List.fromList(utf8.encode("Some Label"));

      await FindexRedisImplementation.init();

      expect(
          await FindexRedisImplementation.count(RedisTable.users), equals(100));
      expect(
          await FindexRedisImplementation.count(RedisTable.entries), equals(0));
      expect(
          await FindexRedisImplementation.count(RedisTable.chains), equals(0));

      await FindexRedisImplementation.indexAll(masterKey, label);

      expect(await FindexRedisImplementation.count(RedisTable.entries),
          equals(583));
      expect(await FindexRedisImplementation.count(RedisTable.chains),
          equals(618));

      final searchResults = await FindexRedisImplementation.search(
          masterKey.k, label, [Keyword.fromString("France")]);

      expect(searchResults.length, 1);

      final keyword = searchResults.entries.toList()[0].key;
      final indexedValues = searchResults.entries.toList()[0].value;
      final usersIds = indexedValues.map((indexedValue) {
        return indexedValue.location.bytes[0];
      }).toList();
      usersIds.sort();

      expect(Keyword.fromString("France").toBase64(), keyword.toBase64());
      expect(usersIds, equals(expectedUsersIdsForFrance));
    }, tags: 'redis');

    test('redis multi entry tables', () async {
      final masterKey = FindexMasterKey.fromJson(jsonDecode(
          await File('test/resources/findex/master_key.json').readAsString()));

      final label = Uint8List.fromList(utf8.encode("Some Label"));

      await RedisMultiEntryTables.init();

      expect(await RedisMultiEntryTables.count(RedisTables.users), equals(100));
      expect(
          await RedisMultiEntryTables.count(RedisTables.entries_1), equals(0));
      expect(
          await RedisMultiEntryTables.count(RedisTables.entries_2), equals(0));
      expect(
          await RedisMultiEntryTables.count(RedisTables.chains_1), equals(0));
      expect(
          await RedisMultiEntryTables.count(RedisTables.chains_2), equals(0));

      await RedisMultiEntryTables.upsert_1(masterKey, label, {
        IndexedValue.fromLocation(Location(Uint8List.fromList([1]))): [
          Keyword.fromString("John")
        ]
      });
      await RedisMultiEntryTables.upsert_2(masterKey, label, {
        IndexedValue.fromLocation(Location(Uint8List.fromList([2]))): [
          Keyword.fromString("John")
        ]
      });

      expect(
          await RedisMultiEntryTables.count(RedisTables.entries_1), equals(1));
      expect(
          await RedisMultiEntryTables.count(RedisTables.entries_2), equals(1));
      expect(
          await RedisMultiEntryTables.count(RedisTables.chains_1), equals(1));
      expect(
          await RedisMultiEntryTables.count(RedisTables.chains_2), equals(1));

      log("\n\nSEARCH in flutter");
      final searchResults = await RedisMultiEntryTables.search(
          masterKey.k, label, [Keyword.fromString("John")],
          entryTableNumber: 2);

      expect(searchResults.length, 1);

      final keyword = searchResults.entries.toList()[0].key;
      final indexedValues = searchResults.entries.toList()[0].value;
      final usersIds = indexedValues.map((indexedValue) {
        return indexedValue.location.bytes[0];
      }).toList();
      usersIds.sort();

      expect(Keyword.fromString("John").toBase64(), keyword.toBase64());
      expect(usersIds, equals([1, 2]));
    }, tags: 'redis');
  });
}

==> cloudproof-5.0.0.tar.gz: test/findex/redis_test.dart <==
import 'dart:convert';
import 'dart:io';
import 'dart:typed_data';

import 'package:cloudproof/cloudproof.dart';
import 'package:flutter_test/flutter_test.dart';

import 'findex_redis_implementation.dart';

const expectedUsersIdsForFrance = [
  4,
  5,
  7,
  8,
  14,
  17,
  19,
  20,
  23,
  34,
  37,
  43,
  46,
  48,
  55,
  56,
  60,
  61,
  63,
  65,
  68,
  70,
  71,
  77,
  80,
  82,
  83,
  85,
  86,
  96
];

void main() {
  group('Findex Redis', () {
    test('search/upsert', () async {
      final masterKey = FindexMasterKey.fromJson(jsonDecode(
          await File('test/resources/findex/master_key.json').readAsString()));

      final label = Uint8List.fromList(utf8.encode("Some Label"));

      await FindexRedisImplementation.init();

      expect(
          await FindexRedisImplementation.count(RedisTable.users), equals(100));
      expect(
          await FindexRedisImplementation.count(RedisTable.entries), equals(0));
      expect(
          await FindexRedisImplementation.count(RedisTable.chains), equals(0));

      await FindexRedisImplementation.indexAll(masterKey, label);

      expect(await FindexRedisImplementation.count(RedisTable.entries),
          equals(583));
      expect(await FindexRedisImplementation.count(RedisTable.chains),
          equals(618));

      final searchResults = await FindexRedisImplementation.search(
          masterKey.k, label, [Keyword.fromString("France")]);

      expect(searchResults.length, 1);

      final keyword = searchResults.entries.toList()[0].key;
      final locations = searchResults.entries.toList()[0].value;
      final usersIds = locations.map((location) {
        return location.bytes[0];
      }).toList();
      usersIds.sort();

      expect(Keyword.fromString("France").toBase64(), keyword.toBase64());
      expect(usersIds, equals(expectedUsersIdsForFrance));
    }, tags: 'redis');
  });
}
